@@ -1,3 +1,9 @@
+# Adjust for exposure misclassification
+
+# the following functions feed into adjust_em():
+# adjust_em_val() (data_validation input),
+# adjust_em_coef() (bias_params input)
+
 adjust_em_val <- function(
     data_observed,
     data_validation) {
@@ -11,7 +17,7 @@ adjust_em_val <- function(
   if (is.null(data_validation$misclassified_exposure)) {
     stop(
       paste0(
-        "This function is adjusting for a misclassified exposure.",
+        "Attempting to adjust for a misclassified exposure.",
         "\n",
         "Validation data must have a true and misclassified exposure specified."
       ),
@@ -241,113 +247,17 @@ adjust_em_coef <- function(
 }
 
 
-#' Adust for exposure misclassification.
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `adjust_emc()` was renamed to `adjust_em()`
-#' @keywords internal
-#'
-#' @export
-adjust_emc <- function(
-    data_observed,
-    x_model_coefs,
-    level = 0.95) {
-  lifecycle::deprecate_warn("1.5.3", "adjust_emc()", "adjust_em()")
-  adjust_em(data_observed, x_model_coefs, level)
-}
-
-
-#' Adust for exposure misclassification.
-#'
-#' `adjust_em` returns the exposure-outcome odds ratio and confidence
-#' interval, adjusted for exposure misclassificaiton.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Values for the bias parameters
-#' can be applied as fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for the true and misclassified exposure corresponding to the
-#' observed exposure in `data_observed`.
-#' @param x_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(X=1)) = &delta;<sub>0</sub> + &delta;<sub>1</sub>X* + &delta;<sub>2</sub>Y + &delta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(X=1)) = \delta_0 + \delta_1 X^* + \delta_2 Y + \delta_{2+j} C_j, }}
-#' where *X* represents the binary true exposure, *X** is the binary
-#' misclassified exposure, *Y* is the outcome, *C* represents
-#' the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders. The number
-#' of parameters is therefore 3 + *j*.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_em,
-#'   exposure = "Xstar",
-#'   outcome = "Y",
-#'   confounders = "C1"
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_em_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = "C1",
-#'   misclassified_exposure = "Xstar"
-#' )
-#'
-#' adjust_em(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using x_model_coefs -------------------------------------------------------
-#' adjust_em(
-#'   data_observed = df_observed,
-#'   x_model_coefs = c(-2.10, 1.62, 0.63, 0.35)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats lm
-#' @importFrom stats qnorm
-#' @importFrom stats rbinom
-#' @importFrom stats plogis
-#' @importFrom stats coef
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_em <- function(
     data_observed,
     data_validation = NULL,
-    x_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
   if (
-    (!is.null(data_validation) && !is.null(x_model_coefs)) ||
-      (is.null(data_validation) && is.null(x_model_coefs))
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
   ) {
     stop(
-      "One of data_validation or x_model_coefs must be non-null.",
+      "One of data_validation or bias_params must be non-null.",
       call. = FALSE
     )
   }
@@ -367,10 +277,16 @@ adjust_em <- function(
       data_observed,
       data_validation
     )
-  } else if (!is.null(x_model_coefs)) {
+  } else if (!is.null(bias_params)) {
+    if (is.null(bias_params$coef_list$x)) {
+      stop(
+        "bias_params must specify parameters for x to adjust for exposure misclassification",
+        call. = FALSE
+      )
+    }
     final <- adjust_em_coef(
       data_observed,
-      x_model_coefs
+      x_model_coefs = bias_params$coef_list$x
     )
   }
 
