@@ -1,26 +1,28 @@
+# Adjust for exposure misclassification and selection bias
+
+# the following functions feed into adjust_em_sel():
+# adjust_em_sel_val() (data_validation input),
+# adjust_em_sel_coef() (bias_params input)
+
 adjust_em_sel_val <- function(
     data_observed,
     data_validation) {
   if (!all(data_observed$confounders %in% data_validation$confounders)) {
-    stop("All confounders in observed data must be present in validation data.", call. = FALSE)
-  }
-
-  if (is.null(data_validation$misclassified_exposure)) {
     stop(
-      paste0(
-        "This function is adjusting for a misclassified exposure.",
-        "\n",
-        "Validation data must have a true and misclassified exposure specified."
-      ),
+      "All confounders in observed data must be present in validation data.",
       call. = FALSE
     )
   }
-  if (is.null(data_validation$selection)) {
+
+  if (
+    is.null(data_validation$misclassified_exposure) ||
+      is.null(data_validation$selection)
+  ) {
     stop(
       paste0(
-        "This function is adjusting for selection bias.",
+        "Attempting to adjust for a misclassified exposure and selection bias.",
         "\n",
-        "Validation data must have a selection indicator column specified."
+        "Validation data must have: 1) a true and misclassified exposure specified, 2) a selection indicator column specified."
       ),
       call. = FALSE
     )
@@ -363,127 +365,20 @@ adjust_em_sel_coef <- function(
 }
 
 
-#' Adust for exposure misclassification and selection bias.
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `adjust_emc_sel()` was renamed to `adjust_em_sel()`
-#' @keywords internal
-#'
-#' @export
-adjust_emc_sel <- function(
-    data_observed,
-    x_model_coefs,
-    s_model_coefs,
-    level = 0.95) {
-  lifecycle::deprecate_warn("1.5.3", "adjust_emc_sel()", "adjust_em_sel()")
-  adjust_em_sel(
-    data_observed,
-    x_model_coefs,
-    s_model_coefs,
-    level
-  )
-}
-
-
-#' Adust for exposure misclassification and selection bias.
-#'
-#' `adjust_em_sel` returns the exposure-outcome odds ratio and confidence
-#' interval, adjusted for exposure misclassification and selection bias.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Values for the bias parameters
-#' can be applied as fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for the true and misclassified exposure,
-#' corresponding to the observed exposure in `data_observed`. There should also
-#' be a selection indicator representing whether the observation in
-#' `data_validation` was selected in `data_observed`.
-#' @param x_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(X=1)) = &delta;<sub>0</sub> + &delta;<sub>1</sub>X* + &delta;<sub>2</sub>Y + &delta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(X=1)) = \delta_0 + \delta_1 X^* + \delta_2 Y + \delta{2+j} C_j, }}
-#' where *X* represents the binary true exposure, *X** is the
-#' binary misclassified exposure, *Y* is the outcome,
-#' *C* represents the vector of
-#' measured confounders (if any), and *j* corresponds to the number of
-#' measured confounders. The number of parameters is therefore 3 + *j*.
-#' @param s_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(S=1)) = &beta;<sub>0</sub> + &beta;<sub>1</sub>X* + &beta;<sub>2</sub>Y + &beta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(S=1)) = \beta_0 + \beta_1 X^* + \beta_2 Y + \beta{{2+j}} C_j, }}
-#' where *S* represents binary selection, *X** is the
-#' binary misclassified exposure,
-#' *Y* is the outcome, *C* represents the vector of
-#' measured confounders (if any), and *j* corresponds to the number of
-#' measured confounders. The number of parameters is therefore 3 + *j*.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_em_sel,
-#'   exposure = "Xstar",
-#'   outcome = "Y",
-#'   confounders = "C1"
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_em_sel_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = "C1",
-#'   misclassified_exposure = "Xstar",
-#'   selection = "S"
-#' )
-#'
-#' adjust_em_sel(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using x_model_coefs and s_model_coefs -------------------------------------
-#' adjust_em_sel(
-#'   data_observed = df_observed,
-#'   x_model_coefs = c(-2.78, 1.62, 0.58, 0.34),
-#'   s_model_coefs = c(0.04, 0.18, 0.92, 0.05)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats lm
-#' @importFrom stats qnorm
-#' @importFrom stats plogis
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_em_sel <- function(
     data_observed,
     data_validation = NULL,
-    x_model_coefs = NULL,
-    s_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
-  check_inputs2(
-    data_validation,
-    list(x_model_coefs, s_model_coefs)
-  )
+  if (
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
+  ) {
+    stop(
+      "One of data_validation or bias_params must be non-null.",
+      call. = FALSE
+    )
+  }
 
   data <- data_observed$data
   xstar <- data[, data_observed$exposure]
@@ -500,11 +395,20 @@ adjust_em_sel <- function(
       data_observed,
       data_validation
     )
-  } else if (!is.null(x_model_coefs)) {
+  } else if (!is.null(bias_params)) {
+    if (is.null(bias_params$coef_list$x) && is.null(bias_params$coef_list$s)) {
+      stop(
+        paste0(
+          "bias_params must specify parameters for exposure ",
+          "misclassification and selection bias"
+        ),
+        call. = FALSE
+      )
+    }
     final <- adjust_em_sel_coef(
       data_observed,
-      x_model_coefs,
-      s_model_coefs
+      bias_params$coef_list$x,
+      bias_params$coef_list$s
     )
   }
 
