@@ -1,3 +1,9 @@
+# Adjust for selection bias
+
+# the following functions feed into adjust_sel():
+# adjust_sel_val() (data_validation input),
+# adjust_sel_coef() (bias_params input)
+
 adjust_sel_val <- function(
     data_observed,
     data_validation) {
@@ -11,7 +17,7 @@ adjust_sel_val <- function(
   if (is.null(data_validation$selection)) {
     stop(
       paste0(
-        "This function is adjusting for selection bias.",
+        "Attempting to adjust for selection bias.",
         "\n",
         "Validation data must have a selection indicator column specified."
       ),
@@ -234,91 +240,17 @@ adjust_sel_coef <- function(
 }
 
 
-#' Adust for selection bias.
-#'
-#' `adjust_sel` returns the exposure-outcome odds ratio and confidence
-#' interval, adjusted for selection bias.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Values for the bias parameters
-#' can be applied as fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for the selection indicator representing whether the
-#' observation was selected in `data_observed`.
-#' @param s_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(S=1)) = &beta;<sub>0</sub> + &beta;<sub>1</sub>X + &beta;<sub>2</sub>Y, }}{\eqn{logit(P(S=1)) = \beta_0 + \beta_1 X + \beta_2 Y, }}
-#' where *S* represents binary selection, *X* is the exposure,
-#' and *Y* is the outcome. The number of parameters is therefore 3.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_sel,
-#'   exposure = "X",
-#'   outcome = "Y",
-#'   confounders = "C1"
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_sel_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = "C1",
-#'   selection = "S"
-#' )
-#'
-#' adjust_sel(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using s_model_coefs -------------------------------------------------------
-#' adjust_sel(
-#'   data_observed = df_observed,
-#'   s_model_coefs = c(0, 0.9, 0.9)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats lm
-#' @importFrom stats qnorm
-#' @importFrom stats plogis
-#' @importFrom stats coef
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_sel <- function(
     data_observed,
     data_validation = NULL,
-    s_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
   if (
-    (!is.null(data_validation) && !is.null(s_model_coefs)) ||
-      (is.null(data_validation) && is.null(s_model_coefs))
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
   ) {
     stop(
-      "One of data_validation or s_model_coefs must be non-null.",
+      "One of data_validation or bias_params must be non-null.",
       call. = FALSE
     )
   }
@@ -338,10 +270,16 @@ adjust_sel <- function(
       data_observed,
       data_validation
     )
-  } else if (!is.null(s_model_coefs)) {
+  } else if (!is.null(bias_params)) {
+    if (is.null(bias_params$coef_list$s)) {
+      stop(
+        "bias_params must specify parameters for s to adjust for selection bias",
+        call. = FALSE
+      )
+    }
     final <- adjust_sel_coef(
       data_observed,
-      s_model_coefs
+      s_model_coefs = bias_params$coef_list$s
     )
   }
 
