@@ -1,3 +1,9 @@
+# Adjust for uncontrolled confounding and exposure misclassification
+
+# the following functions feed into adjust_uc_em():
+# adjust_uc_em_val() (data_validation input),
+# adjust_uc_em_coef() (bias_params input)
+
 adjust_uc_em_val <- function(
     data_observed,
     data_validation) {
@@ -9,23 +15,14 @@ adjust_uc_em_val <- function(
   }
 
   if (
-    length(data_validation$confounders) - length(data_observed$confounders) != 1
+    (length(data_validation$confounders) - length(data_observed$confounders) != 1) ||
+      (is.null(data_validation$misclassified_exposure))
   ) {
     stop(
       paste0(
-        "This function adjusts for unobserved confounding from one confounder.",
+        "Attempting to adjust for unobserved confounding from one confounder and exposure misclassification.",
         "\n",
-        "Validation data must have one more confounder than the observed data."
-      ),
-      call. = FALSE
-    )
-  }
-  if (is.null(data_validation$misclassified_exposure)) {
-    stop(
-      paste0(
-        "This function is adjusting for a misclassified exposure.",
-        "\n",
-        "Validation data must have a true and misclassified exposure specified."
+        "Validation data must have: 1) one more confounder than the observed data, 2) a true and misclassified exposure specified."
       ),
       call. = FALSE
     )
@@ -644,171 +641,20 @@ adjust_uc_em_coef_multinom <- function(
 }
 
 
-#' Adust for uncontrolled confounding and exposure misclassification.
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `adjust_uc_emc()` was renamed to `adjust_uc_em()`
-#' @keywords internal
-#'
-#' @export
-adjust_uc_emc <- function(
-    data_observed,
-    u_model_coefs = NULL,
-    x_model_coefs = NULL,
-    x1u0_model_coefs = NULL,
-    x0u1_model_coefs = NULL,
-    x1u1_model_coefs = NULL,
-    level = 0.95) {
-  lifecycle::deprecate_warn(
-    "1.5.3", "adjust_uc_emc()", "adjust_uc_em()"
-  )
-  adjust_uc_em(
-    data_observed,
-    u_model_coefs,
-    x_model_coefs,
-    x1u0_model_coefs,
-    x0u1_model_coefs,
-    x1u1_model_coefs,
-    level
-  )
-}
-
-
-#' Adust for uncontrolled confounding and exposure misclassification.
-#'
-#' `adjust_uc_em` returns the exposure-outcome odds ratio and confidence
-#' interval, adjusted for uncontrolled confounding and exposure
-#' misclassificaiton.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Two different options for the bias parameters
-#' are available here: 1) parameters from separate models of *U* and *X*
-#' (`u_model_coefs` and `x_model_coefs`) or 2) parameters from a
-#' joint model of *U* and *X* (`x1u0_model_coefs`,
-#' `x0u1_model_coefs`, and `x1u1_model_coefs`).
-#'
-#' Values for the bias parameters can be applied as
-#' fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for the true and misclassified exposure corresponding to the
-#' observed exposure in `data_observed`.
-#' There should also be data for the confounder missing in `data_observed`.
-#' @param u_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(U=1)) = &alpha;<sub>0</sub> + &alpha;<sub>1</sub>X + &alpha;<sub>2</sub>Y, }}{\eqn{logit(P(U=1)) = \alpha_0 + \alpha_1 X + \alpha_2 Y, }}
-#' where *U* is the binary unmeasured confounder, *X* is the
-#' binary true exposure, and *Y* is the outcome.
-#' The number of parameters therefore equals 3.
-#' @param x_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(X=1)) = &delta;<sub>0</sub> + &delta;<sub>1</sub>X* + &delta;<sub>2</sub>Y + &delta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(X=1)) = \delta_0 + \delta_1 X^* + \delta_2 Y + \delta_{2+j} C_j, }}
-#' where *X* represents the binary true exposure,
-#' *X** is the binary misclassified exposure, *Y* is the
-#' outcome, and *C* represents the vector of measured confounders
-#' (if any), and *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param x1u0_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=1,U=0)/P(X=0,U=0)) = &gamma;<sub>1,0</sub> + &gamma;<sub>1,1</sub>X* + &gamma;<sub>1,2</sub>Y + &gamma;<sub>1,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=1,U=0)/P(X=0,U=0)) = \gamma_{1,0} + \gamma_{1,1} X^* + \gamma_{1,2} Y + \gamma_{1,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary unmeasured
-#' confounder, *X** is the binary misclassified exposure, *Y* is the
-#' outcome, *C* represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders.
-#' @param x0u1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=0,U=1)/P(X=0,U=0)) = &gamma;<sub>2,0</sub> + &gamma;<sub>2,1</sub>X* + &gamma;<sub>2,2</sub>Y + &gamma;<sub>2,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=0,U=1)/P(X=0,U=0)) = \gamma_{2,0} + \gamma_{2,1} X^* + \gamma_{2,2} Y + \gamma_{2,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary unmeasured
-#' confounder, *X** is the binary misclassified exposure, *Y* is the
-#' outcome, *C* represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders.
-#' @param x1u1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=1,U=1)/P(X=0,U=0)) = &gamma;<sub>3,0</sub> + &gamma;<sub>3,1</sub>X* + &gamma;<sub>3,2</sub>Y + &gamma;<sub>3,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=1,U=1)/P(X=0,U=0)) = \gamma_{3,0} + \gamma_{3,1} X^* + \gamma_{3,2} Y + \gamma_{3,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary unmeasured
-#' confounder, *X** is the binary misclassified exposure, *Y* is the
-#' outcome, *C* represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_uc_em,
-#'   exposure = "Xstar",
-#'   outcome = "Y",
-#'   confounders = "C1"
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_uc_em_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = c("C1", "U"),
-#'   misclassified_exposure = "Xstar",
-#' )
-#'
-#' adjust_uc_em(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using u_model_coefs and x_model_coefs -------------------------------------
-#' adjust_uc_em(
-#'   data_observed = df_observed,
-#'   u_model_coefs = c(-0.23, 0.63, 0.66),
-#'   x_model_coefs = c(-2.47, 1.62, 0.73, 0.32)
-#' )
-#'
-#' # Using x1u0_model_coefs, x0u1_model_coefs, x1u1_model_coefs ----------------
-#' adjust_uc_em(
-#'   data_observed = df_observed,
-#'   x1u0_model_coefs = c(-2.82, 1.62, 0.68, -0.06),
-#'   x0u1_model_coefs = c(-0.20, 0.00, 0.68, -0.05),
-#'   x1u1_model_coefs = c(-2.36, 1.62, 1.29, 0.27)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats qnorm
-#' @importFrom stats rbinom
-#' @importFrom stats plogis
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_uc_em <- function(
     data_observed,
     data_validation = NULL,
-    u_model_coefs = NULL,
-    x_model_coefs = NULL,
-    x1u0_model_coefs = NULL,
-    x0u1_model_coefs = NULL,
-    x1u1_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
-  check_inputs3(
-    data_validation,
-    list(u_model_coefs, x_model_coefs),
-    list(x1u0_model_coefs, x0u1_model_coefs, x1u1_model_coefs)
-  )
+  if (
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
+  ) {
+    stop(
+      "One of data_validation or bias_params must be non-null.",
+      call. = FALSE
+    )
+  }
 
   data <- data_observed$data
   xstar <- data[, data_observed$exposure]
@@ -825,19 +671,36 @@ adjust_uc_em <- function(
       data_observed,
       data_validation
     )
-  } else if (!is.null(x_model_coefs)) {
-    final <- adjust_uc_em_coef_single(
-      data_observed = data_observed,
-      u_model_coefs = u_model_coefs,
-      x_model_coefs = x_model_coefs
-    )
-  } else if (!is.null(x1u0_model_coefs)) {
-    final <- adjust_uc_em_coef_multinom(
-      data_observed = data_observed,
-      x1u0_model_coefs = x1u0_model_coefs,
-      x0u1_model_coefs = x0u1_model_coefs,
-      x1u1_model_coefs = x1u1_model_coefs
-    )
+  } else if (!is.null(bias_params)) {
+    if (all(c("x", "u") %in% names(bias_params$coef_list))) {
+      final <- adjust_uc_em_coef_single(
+        data_observed,
+        u_model_coefs = bias_params$coef_list$u,
+        x_model_coefs = bias_params$coef_list$x
+      )
+    } else if (
+      all(
+        c("x1u0", "x0u1", "x1u1") %in%
+          names(bias_params$coef_list)
+      )
+    ) {
+      final <- adjust_uc_em_coef_multinom(
+        data_observed,
+        x1u0_model_coefs = bias_params$coef_list$x1u0,
+        x0u1_model_coefs = bias_params$coef_list$x0u1,
+        x1u1_model_coefs = bias_params$coef_list$x1u1
+      )
+    } else {
+      (
+        stop(
+          paste0(
+            "bias_params must specify parameters for ",
+            "exposure misclassification and uncontrolled confounding"
+          ),
+          call. = FALSE
+        )
+      )
+    }
   }
 
   est <- summary(final)$coef[2, 1]
