@@ -1,3 +1,11 @@
+# Adjust for uncontrolled confounding, exposure misclassification,
+# and selection bias
+
+# the following functions feed into adjust_uc_em_sel():
+# adjust_uc_em_sel_val() (data_validation input),
+# adjust_uc_em_sel_coef_single() (bias_params input),
+# adjust_uc_em_sel_coef_multinom() (bias_params input)
+
 adjust_uc_em_sel_val <- function(
     data_observed,
     data_validation) {
@@ -9,33 +17,15 @@ adjust_uc_em_sel_val <- function(
   }
 
   if (
-    length(data_validation$confounders) - length(data_observed$confounders) != 1
+    length(data_validation$confounders) - length(data_observed$confounders) != 1 ||
+      is.null(data_validation$misclassified_exposure) ||
+      is.null(data_validation$selection)
   ) {
     stop(
       paste0(
-        "This function adjusts for unobserved confounding from one confounder.",
+        "This function is adjusting for three biases: uncontrolled confounding, exposure misclassification, and selection bias.",
         "\n",
-        "Validation data must have one more confounder than the observed data."
-      ),
-      call. = FALSE
-    )
-  }
-  if (is.null(data_validation$misclassified_exposure)) {
-    stop(
-      paste0(
-        "This function is adjusting for a misclassified exposure.",
-        "\n",
-        "Validation data must have a true and misclassified exposure specified."
-      ),
-      call. = FALSE
-    )
-  }
-  if (is.null(data_validation$selection)) {
-    stop(
-      paste0(
-        "This function is adjusting for selection bias.",
-        "\n",
-        "Validation data must have a selection indicator column specified."
+        "Validation data must have: 1) one more confounder than the observed data, 2) a true and misclassified exposure specified, 3) a selection indicator column specified."
       ),
       call. = FALSE
     )
@@ -787,196 +777,20 @@ adjust_uc_em_sel_coef_multinom <- function(
 }
 
 
-#' Adust for uncontrolled confounding, exposure misclassification, and selection
-#' bias.
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `adjust_uc_emc_sel()` was renamed to `adjust_uc_em_sel()`
-#' @keywords internal
-#'
-#' @export
-adjust_uc_emc_sel <- function(
-    data_observed,
-    u_model_coefs = NULL,
-    x_model_coefs = NULL,
-    x1u0_model_coefs = NULL,
-    x0u1_model_coefs = NULL,
-    x1u1_model_coefs = NULL,
-    s_model_coefs,
-    level = 0.95) {
-  lifecycle::deprecate_warn(
-    "1.5.3", "adjust_uc_emc_sel()", "adjust_uc_em_sel()"
-  )
-  adjust_uc_em_sel(
-    data_observed,
-    u_model_coefs,
-    x_model_coefs,
-    x1u0_model_coefs,
-    x0u1_model_coefs,
-    x1u1_model_coefs,
-    s_model_coefs,
-    level
-  )
-}
-
-
-#' Adust for uncontrolled confounding, exposure misclassification, and selection
-#' bias.
-#'
-#' `adjust_uc_em_sel` returns the exposure-outcome odds ratio and
-#' confidence interval, adjusted for uncontrolled confounding, exposure
-#' misclassificaiton, and selection bias.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Two different options for the bias
-#' parameters are availale here: 1) parameters from separate models
-#' of *U* and *X* (`u_model_coefs` and `x_model_coefs`)
-#' or 2) parameters from a joint model of *U* and *X*
-#' (`x1u0_model_coefs`, `x0u1_model_coefs`, and
-#' `x1u1_model_coefs`). Both approaches require `s_model_coefs`.
-#'
-#' Values for the bias parameters can be applied as
-#' fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for: 1) the true and misclassified exposure corresponding
-#' to the observed exposure in `data_observed`, 2) the confounder missing in
-#' `data_observed`, 3) a selection indicator representing whether the
-#' observation in `data_validation` was selected in `data_observed`.
-#' @param u_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(U=1)) = &alpha;<sub>0</sub> + &alpha;<sub>1</sub>X + &alpha;<sub>2</sub>Y, }}{\eqn{logit(P(U=1)) = \alpha_0 + \alpha_1 X + \alpha_2 Y, }}
-#' where *U* is the binary unmeasured confounder, *X* is the
-#' binary true exposure, and *Y* is the outcome.
-#' The number of parameters therefore equals 3.
-#' @param x_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(X=1)) = &delta;<sub>0</sub> + &delta;<sub>1</sub>X* + &delta;<sub>2</sub>Y + &delta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(X=1)) = \delta_0 + \delta_1 X^* + \delta_2 Y + \delta_{2+j} C_j, }}
-#' where *X* represents binary true exposure, *X** is the
-#' binary misclassified exposure, *Y* is the outcome, *C*
-#' represents the vector of measured confounders (if any), and
-#' *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param x1u0_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=1,U=0)/P(X=0,U=0)) = &gamma;<sub>1,0</sub> + &gamma;<sub>1,1</sub>X* + &gamma;<sub>1,2</sub>Y + &gamma;<sub>1,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=1,U=0)/P(X=0,U=0)) = \gamma_{1,0} + \gamma_{1,1} X^* + \gamma_{1,2} Y + \gamma_{1,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary
-#' unmeasured confounder, *X** is the binary misclassified exposure,
-#' *Y* is the outcome, *C* represents the vector of measured confounders
-#' (if any), and *j* corresponds to the number of measured confounders.
-#' @param x0u1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=0,U=1)/P(X=0,U=0)) = &gamma;<sub>2,0</sub> + &gamma;<sub>2,1</sub>X* + &gamma;<sub>2,2</sub>Y + &gamma;<sub>2,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=0,U=1)/P(X=0,U=0)) = \gamma_{2,0} + \gamma_{2,1} X^* + \gamma_{2,2} Y + \gamma_{2,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary
-#' unmeasured confounder, *X** is the binary misclassified exposure,
-#' *Y* is the outcome,
-#' *C* represents the vector of measured confounders (if any), and
-#' *j* corresponds to the number of measured confounders.
-#' @param x1u1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(X=1,U=1)/P(X=0,U=0)) = &gamma;<sub>3,0</sub> + &gamma;<sub>3,1</sub>X* + &gamma;<sub>3,2</sub>Y + &gamma;<sub>3,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(X=1,U=1)/P(X=0,U=0)) = \gamma_{3,0} + \gamma_{3,1} X^* + \gamma_{3,2} Y + \gamma_{3,2+j} C_j, }}
-#' where *X* is the binary true exposure, *U* is the binary
-#' unmeasured confounder, *X** is the binary misclassified exposure,
-#' *Y* is the outcome,
-#' *C* represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders.
-#' @param s_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(S=1)) = &beta;<sub>0</sub> + &beta;<sub>1</sub>X* + &beta;<sub>2</sub>Y + &beta;<sub>2+j</sub>C<sub>2+j</sub>, }}{\eqn{logit(P(S=1)) = \beta_0 + \beta_1 X^* + \beta_2 Y + \beta_{2+j} C_j, }}
-#' where *S* represents binary selection, *X** is the
-#' binary misclassified exposure, *Y* is the outcome,
-#' *C* represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_uc_em_sel,
-#'   exposure = "Xstar",
-#'   outcome = "Y",
-#'   confounders = c("C1", "C2", "C3")
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_uc_em_sel_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = c("C1", "C2", "C3", "U"),
-#'   misclassified_exposure = "Xstar",
-#'   selection = "S"
-#' )
-#'
-#' adjust_uc_em_sel(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using u_model_coefs, x_model_coefs, s_model_coefs -------------------------
-#' adjust_uc_em_sel(
-#'   data_observed = df_observed,
-#'   u_model_coefs = c(-0.32, 0.59, 0.69),
-#'   x_model_coefs = c(-2.44, 1.62, 0.72, 0.32, -0.15, 0.85),
-#'   s_model_coefs = c(0.00, 0.26, 0.78, 0.03, -0.02, 0.10)
-#' )
-#'
-#' # Using x1u0_model_coefs, x0u1_model_coefs, x1u1_model_coefs, s_model_coefs
-#' adjust_uc_em_sel(
-#'   data_observed = df_observed,
-#'   x1u0_model_coefs = c(-2.78, 1.62, 0.61, 0.36, -0.27, 0.88),
-#'   x0u1_model_coefs = c(-0.17, -0.01, 0.71, -0.08, 0.07, -0.15),
-#'   x1u1_model_coefs = c(-2.36, 1.62, 1.29, 0.25, -0.06, 0.74),
-#'   s_model_coefs = c(0.00, 0.26, 0.78, 0.03, -0.02, 0.10)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats qnorm
-#' @importFrom stats rbinom
-#' @importFrom stats plogis
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_uc_em_sel <- function(
     data_observed,
     data_validation = NULL,
-    u_model_coefs = NULL,
-    x_model_coefs = NULL,
-    x1u0_model_coefs = NULL,
-    x0u1_model_coefs = NULL,
-    x1u1_model_coefs = NULL,
-    s_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
-  check_inputs3(
-    input1 = data_validation,
-    input2 = list(u_model_coefs, x_model_coefs, s_model_coefs),
-    input3 = list(
-      x1u0_model_coefs,
-      x0u1_model_coefs,
-      x1u1_model_coefs,
-      s_model_coefs
-    ),
-    ignore = s_model_coefs
-  )
+  if (
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
+  ) {
+    stop(
+      "One of data_validation or bias_params must be non-null.",
+      call. = FALSE
+    )
+  }
 
   data <- data_observed$data
   xstar <- data[, data_observed$exposure]
@@ -993,21 +807,38 @@ adjust_uc_em_sel <- function(
       data_observed,
       data_validation
     )
-  } else if (!is.null(x_model_coefs)) {
-    final <- adjust_uc_em_sel_coef_single(
-      data_observed = data_observed,
-      u_model_coefs = u_model_coefs,
-      x_model_coefs = x_model_coefs,
-      s_model_coefs = s_model_coefs
-    )
-  } else if (!is.null(x1u0_model_coefs)) {
-    final <- adjust_uc_em_sel_coef_multinom(
-      data_observed = data_observed,
-      x1u0_model_coefs = x1u0_model_coefs,
-      x0u1_model_coefs = x0u1_model_coefs,
-      x1u1_model_coefs = x1u1_model_coefs,
-      s_model_coefs = s_model_coefs
-    )
+  } else if (!is.null(bias_params)) {
+    if (all(c("u", "x", "s") %in% names(bias_params$coef_list))) {
+      final <- adjust_uc_em_sel_coef_single(
+        data_observed,
+        u_model_coefs = bias_params$coef_list$u,
+        x_model_coefs = bias_params$coef_list$x,
+        s_model_coefs = bias_params$coef_list$s
+      )
+    } else if (
+      all(
+        c("x1u0", "x0u1", "x1u1", "s") %in%
+          names(bias_params$coef_list)
+      )
+    ) {
+      final <- adjust_uc_em_sel_coef_multinom(
+        data_observed,
+        x1u0_model_coefs = bias_params$coef_list$x1u0,
+        x0u1_model_coefs = bias_params$coef_list$x0u1,
+        x1u1_model_coefs = bias_params$coef_list$x1u1,
+        s_model_coefs = bias_params$coef_list$s
+      )
+    } else {
+      (
+        stop(
+          paste0(
+            "bias_params must specify parameters for uncontrolled ",
+            "confounding, exposure misclassification, and selection bias"
+          ),
+          call. = FALSE
+        )
+      )
+    }
   }
 
   est <- summary(final)$coef[2, 1]
