@@ -1,3 +1,11 @@
+# Adjust for uncontrolled confounding, outcome misclassification,
+# and selection bias
+
+# the following functions feed into adjust_uc_om_sel():
+# adjust_uc_om_sel_val() (data_validation input),
+# adjust_uc_om_sel_coef_single() (bias_params input),
+# adjust_uc_om_sel_coef_multinom() (bias_params input)
+
 adjust_uc_om_sel_val <- function(
     data_observed,
     data_validation) {
@@ -9,33 +17,15 @@ adjust_uc_om_sel_val <- function(
   }
 
   if (
-    length(data_validation$confounders) - length(data_observed$confounders) != 1
+    length(data_validation$confounders) - length(data_observed$confounders) != 1 ||
+      is.null(data_validation$misclassified_outcome) ||
+      is.null(data_validation$selection)
   ) {
     stop(
       paste0(
-        "This function adjusts for unobserved confounding from one confounder.",
+        "This function is adjusting for three biases: uncontrolled confounding, outcome misclassification, and selection bias.",
         "\n",
-        "Validation data must have one more confounder than the observed data."
-      ),
-      call. = FALSE
-    )
-  }
-  if (is.null(data_validation$misclassified_outcome)) {
-    stop(
-      paste0(
-        "This function is adjusting for a misclassified outcome.",
-        "\n",
-        "Validation data must have a true and misclassified outcome specified."
-      ),
-      call. = FALSE
-    )
-  }
-  if (is.null(data_validation$selection)) {
-    stop(
-      paste0(
-        "This function is adjusting for selection bias.",
-        "\n",
-        "Validation data must have a selection indicator column specified."
+        "Validation data must have: 1) one more confounder than the observed data, 2) a true and misclassified outcome specified, 3) a selection indicator column specified."
       ),
       call. = FALSE
     )
@@ -679,221 +669,58 @@ adjust_uc_om_sel_coef_multinom <- function(
 }
 
 
-#' Adust for uncontrolled confounding, outcome misclassification, and selection
-#' bias.
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `adjust_uc_omc_sel()` was renamed to `adjust_uc_om_sel()`
-#' @keywords internal
-#'
-#' @export
-adjust_uc_omc_sel <- function(
-    data_observed,
-    u_model_coefs = NULL,
-    y_model_coefs = NULL,
-    u0y1_model_coefs = NULL,
-    u1y0_model_coefs = NULL,
-    u1y1_model_coefs = NULL,
-    s_model_coefs,
-    level = 0.95) {
-  lifecycle::deprecate_warn(
-    "1.5.3", "adjust_uc_omc_sel()", "adjust_uc_om_sel()"
-  )
-  adjust_uc_om_sel(
-    data_observed,
-    u_model_coefs,
-    y_model_coefs,
-    u0y1_model_coefs,
-    u1y0_model_coefs,
-    u1y1_model_coefs,
-    s_model_coefs,
-    level
-  )
-}
-
-
-#' Adust for uncontrolled confounding, outcome misclassification, and selection
-#' bias.
-#'
-#' `adjust_uc_om_sel` returns the exposure-outcome odds ratio and
-#' confidence interval, adjusted for uncontrolled confounding, outcome
-#' misclassificaiton, and selection bias.
-#'
-#' Bias adjustment can be performed by inputting either a validation dataset or
-#' the necessary bias parameters. Two different options for the bias
-#' parameters are availale here: 1) parameters from separate models
-#' of *U* and *Y* (`u_model_coefs` and `y_model_coefs`)
-#' or 2) parameters from a joint model of *U* and *Y*
-#' (`u1y0_model_coefs`, `u0y1_model_coefs`, and
-#' `u1y1_model_coefs`). Both approaches require `s_model_coefs`.
-#'
-#' Values for the regression coefficients can be applied as
-#' fixed values or as single draws from a probability
-#' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
-#' the advantage of allowing the researcher to capture the uncertainty
-#' in the bias parameter estimates. To incorporate this uncertainty in the
-#' estimate and confidence interval, this function should be run in loop across
-#' bootstrap samples of the dataframe for analysis. The estimate and
-#' confidence interval would then be obtained from the median and quantiles
-#' of the distribution of odds ratio estimates.
-#'
-#' @param data_observed Object of class `data_observed` corresponding to the
-#' data to perform bias analysis on.
-#' @param data_validation Object of class `data_validation` corresponding to
-#' the validation data used to adjust for bias in the observed data. Here, the
-#' validation data should have data for the same variables as in the observed
-#' data, plus data for: 1) the true and misclassified outcome corresponding
-#' to the observed outcome in `data_observed`, 2) the confounder missing in
-#' `data_observed`, 3) a selection indicator representing whether the
-#' observation in `data_validation` was selected in `data_observed`.
-#' @param u_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(U=1)) = &alpha;<sub>0</sub> + &alpha;<sub>1</sub>X + &alpha;<sub>2</sub>Y, }}{\eqn{logit(P(U=1)) = \alpha_0 + \alpha_1 X + \alpha_2 Y, }}
-#' where *U* is the binary unmeasured confounder, *X* is the
-#' exposure, and *Y* is the binary true outcome.
-#' The number of parameters therefore equals 3.
-#' @param y_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(Y=1)) = &delta;<sub>0</sub> + &delta;<sub>1</sub>X + &delta;<sub>2</sub>Y* + &delta;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(Y=1)) = \delta_0 + \delta_1 X + \delta_2 Y^* + \delta_{2+j} C_j, }}
-#' where *Y* represents binary true outcome, *X* is the
-#' exposure, *Y** is the binary misclassified outcome, *C*
-#' represents the vector of measured confounders (if any),
-#' and *j* corresponds to the number of measured
-#' confounders. The number of parameters therefore equals 3 + *j*.
-#' @param u1y0_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(U=1,Y=0)/P(U=0,Y=0)) = &gamma;<sub>1,0</sub> + &gamma;<sub>1,1</sub>X + &gamma;<sub>1,2</sub>Y* + &gamma;<sub>1,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(U=1,Y=0)/P(U=0,Y=0)) = \gamma_{1,0} + \gamma_{1,1} X + \gamma_{1,2} Y^* + \gamma_{1,2+j} C_j, }}
-#' where *U* is the binary unmeasured confounder,
-#' *Y* is the binary true outcome,
-#' *X* is the exposure, *Y** is the binary misclassified outcome,
-#' *C* represents the vector of measured confounders (if any), and
-#' *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param u0y1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(U=0,Y=1)/P(U=0,Y=0)) = &gamma;<sub>2,0</sub> + &gamma;<sub>2,1</sub>X + &gamma;<sub>2,2</sub>Y* + &gamma;<sub>2,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(U=0,Y=1)/P(U=0,Y=0)) = \gamma_{2,0} + \gamma_{2,1} X + \gamma_{2,2} Y^* + \gamma_{2,2+j} C_j, }}
-#' where *U* is the binary unmeasured confounder,
-#' *Y* is the binary true outcome,
-#' *X* is the exposure, *Y** is the binary misclassified outcome,
-#' *C* represents the vector of measured confounders (if any), and
-#' *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param u1y1_model_coefs The regression coefficients corresponding to the
-#' model:
-#' \ifelse{html}{\out{log(P(U=1,Y=1)/P(U=0,Y=0)) = &gamma;<sub>3,0</sub> + &gamma;<sub>3,1</sub>X + &gamma;<sub>3,2</sub>Y* + &gamma;<sub>3,2+j</sub>C<sub>j</sub>, }}{\eqn{log(P(U=1,Y=1)/P(U=0,Y=0)) = \gamma_{3,0} + \gamma_{3,1} X + \gamma_{3,2} Y^* + \gamma_{3,2+j} C_j, }}
-#' where *U* is the binary unmeasured confounder,
-#' *Y* is the binary true outcome,
-#' *X* is the exposure, *Y** is the binary misclassified outcome,
-#' *C* represents the vector of measured confounders (if any), and
-#' *j* corresponds to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param s_model_coefs The regression coefficients corresponding to the model:
-#' \ifelse{html}{\out{logit(P(S=1)) = &beta;<sub>0</sub> + &beta;<sub>1</sub>X + &beta;<sub>2</sub>Y* + &beta;<sub>2+j</sub>C<sub>2+j</sub>, }}{\eqn{logit(P(S=1)) = \beta_0 + \beta_1 X + \beta_2 Y^* + \beta_{2+j} C_j, }}
-#' where *S* represents binary selection, *X* is the exposure,
-#' *Y** is the binary misclassified outcome, *C* represents
-#' the vector of measured confounders (if any), and *j* corresponds
-#' to the number of measured confounders.
-#' The number of parameters therefore equals 3 + *j*.
-#' @param level Value from 0-1 representing the full range of the confidence
-#' interval. Default is 0.95.
-#'
-#' @return A list where the first item is the odds ratio estimate of the
-#' effect of the exposure on the outcome and the second item is the
-#' confidence interval as the vector: (lower bound, upper bound).
-#'
-#' @examples
-#' df_observed <- data_observed(
-#'   data = df_uc_om_sel,
-#'   exposure = "X",
-#'   outcome = "Ystar",
-#'   confounders = c("C1", "C2", "C3")
-#' )
-#'
-#' # Using validation data -----------------------------------------------------
-#' df_validation <- data_validation(
-#'   data = df_uc_om_sel_source,
-#'   true_exposure = "X",
-#'   true_outcome = "Y",
-#'   confounders = c("C1", "C2", "C3", "U"),
-#'   misclassified_outcome = "Ystar",
-#'   selection = "S"
-#' )
-#'
-#' adjust_uc_om_sel(
-#'   data_observed = df_observed,
-#'   data_validation = df_validation
-#' )
-#'
-#' # Using u_model_coefs, y_model_coefs, s_model_coefs -------------------------
-#' adjust_uc_om_sel(
-#'   data_observed = df_observed,
-#'   u_model_coefs = c(-0.32, 0.59, 0.69),
-#'   y_model_coefs = c(-2.85, 0.71, 1.63, 0.40, -0.85, 0.22),
-#'   s_model_coefs = c(0.00, 0.74, 0.19, 0.02, -0.06, 0.02)
-#' )
-#'
-#' # Using u1y0_model_coefs, u0y1_model_coefs, u1y1_model_coefs, s_model_coefs
-#' adjust_uc_om_sel(
-#'   data_observed = df_observed,
-#'   u1y0_model_coefs = c(-0.20, 0.62, 0.01, -0.08, 0.10, -0.15),
-#'   u0y1_model_coefs = c(-3.28, 0.63, 1.65, 0.42, -0.85, 0.26),
-#'   u1y1_model_coefs = c(-2.70, 1.22, 1.64, 0.32, -0.77, 0.09),
-#'   s_model_coefs = c(0.00, 0.74, 0.19, 0.02, -0.06, 0.02)
-#' )
-#'
-#' @import dplyr
-#' @importFrom magrittr %>%
-#' @importFrom stats binomial
-#' @importFrom stats glm
-#' @importFrom stats qnorm
-#' @importFrom stats rbinom
-#' @importFrom stats plogis
-#' @importFrom rlang .data
-#'
-#' @export
-
 adjust_uc_om_sel <- function(
     data_observed,
     data_validation = NULL,
-    u_model_coefs = NULL,
-    y_model_coefs = NULL,
-    u0y1_model_coefs = NULL,
-    u1y0_model_coefs = NULL,
-    u1y1_model_coefs = NULL,
-    s_model_coefs = NULL,
+    bias_params = NULL,
     level = 0.95) {
-  check_inputs3(
-    input1 = data_validation,
-    input2 = list(u_model_coefs, y_model_coefs, s_model_coefs),
-    input3 = list(
-      u1y0_model_coefs,
-      u0y1_model_coefs,
-      u1y1_model_coefs,
-      s_model_coefs
-    ),
-    ignore = s_model_coefs
-  )
+  if (
+    (!is.null(data_validation) && !is.null(bias_params)) ||
+      (is.null(data_validation) && is.null(bias_params))
+  ) {
+    stop(
+      "One of data_validation or bias_params must be non-null.",
+      call. = FALSE
+    )
+  }
 
   if (!is.null(data_validation)) {
     final <- adjust_uc_om_sel_val(
       data_observed,
       data_validation
     )
-  } else if (!is.null(y_model_coefs)) {
-    final <- adjust_uc_om_sel_coef_single(
-      data_observed = data_observed,
-      u_model_coefs = u_model_coefs,
-      y_model_coefs = y_model_coefs,
-      s_model_coefs = s_model_coefs
-    )
-  } else if (!is.null(u1y0_model_coefs)) {
-    final <- adjust_uc_om_sel_coef_multinom(
-      data_observed = data_observed,
-      u1y0_model_coefs = u1y0_model_coefs,
-      u0y1_model_coefs = u0y1_model_coefs,
-      u1y1_model_coefs = u1y1_model_coefs,
-      s_model_coefs = s_model_coefs
-    )
+  } else if (!is.null(bias_params)) {
+    if (all(c("u", "y", "s") %in% names(bias_params$coef_list))) {
+      final <- adjust_uc_om_sel_coef_single(
+        data_observed,
+        u_model_coefs = bias_params$coef_list$u,
+        y_model_coefs = bias_params$coef_list$y,
+        s_model_coefs = bias_params$coef_list$s
+      )
+    } else if (
+      all(
+        c("u1y0", "u0y1", "u1y1", "s") %in%
+          names(bias_params$coef_list)
+      )
+    ) {
+      final <- adjust_uc_om_sel_coef_multinom(
+        data_observed,
+        u1y0_model_coefs = bias_params$coef_list$u1y0,
+        u0y1_model_coefs = bias_params$coef_list$u0y1,
+        u1y1_model_coefs = bias_params$coef_list$u1y1,
+        s_model_coefs = bias_params$coef_list$s
+      )
+    } else {
+      (
+        stop(
+          paste0(
+            "bias_params must specify parameters for uncontrolled ",
+            "confounding, outcome misclassification, and selection bias"
+          ),
+          call. = FALSE
+        )
+      )
+    }
   }
 
   est <- summary(final)$coef[2, 1]
